import React, { PureComponent } from 'react';
import {
  View,
  Stylesheet,
  Text,
  TouchableOpacity,
  Dimensions,
  Image,
} from 'react-native';
import TagInput from 'react-native-tag-input';
import { InputItem } from 'antd-mobile';

class UploadPageComponent extends PureComponent {
  onCancel = () => {
    this.props.onCancel();
  };
  onUploadPhoto = () => {
    this.props.onUploadPhoto();
  };
  renderHeaderMenu() {
    return (
      <View style={[styles.view_header_container, { backgroundColor: this.props.bgColor }]}>
        <TouchableOpacity
          onPress={this.onCancel()}
        >
          <Text style={[styles.text_title, { color: this.props.titleColor }]}>取消</Text>
        </TouchableOpacity>
        <Text style={[styles.text_title, { color: this.props.titleColor }]}>传照片</Text>
        <TouchableOpacity
          onPress={this.onUploadPhoto()}
        >
          <Text style={styles.text_right_title}>
            上传
          </Text>
        </TouchableOpacity>
      </View>
    );
  }
  render() {
    const { getFieldProps, getFieldError } = this.props.form;
    return (
      <View style={styles.container}>
        {this.renderHeaderMenu()}
        <Image
          style={{ height: Dimensions.get('window').height, width: Dimensions.get('window').width }}
          source={{ uri: this.props.imageURI, isStatic: true }}
        />
        <InputItem
          {...getFieldProps('account', {
            initialValue: 'little ant',
            rules: [
              { required: true, message: '名称不能为空' },
            ],
          })}
          clear
          error={!!getFieldError('account')}
          placeholder="请输入名字"
        >照片名称
        </InputItem>
      </View>
    );
  }
}
const styles = Stylesheet.create({
  container: {
    flex: 1,
  },
  view_header_container: {
    height: 56,
    backgroundColor: 'white',
    flexDirection: 'row',
    alignItems: 'center',
  },
  text_right_title: {
    color: '#000',
    position: 'absolute',
    right: 16,
  },
  text_left_title: {
    color: '#000',
    position: 'absolute',
    left: 16,
  },
  text_title: {
    color: '#000',
    fontSize: 18,
  },
  uploadImage: {
    height: Dimensions.get('window').height,
    width: Dimensions.get('window').width,
  },
});

export default UploadPageComponent;

